/* -*- C -*-
 * liba2ps.h
 *
 * shared header with the whole package
 * Copyright (c) 1988, 89, 90, 91, 92, 93 Miguel Santana
 * Copyright (c) 1995, 96, 97 Akim Demaille, Miguel Santana
 * $Id: liba2ps.h,v 1.107 1997/11/07 11:34:45 demaille Exp $
 */

/*
 * This file is part of a2ps.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef _LIBA2PS_H_
#define _LIBA2PS_H_

#undef __BEGIN_DECLS
#undef __END_DECLS
#ifdef __cplusplus
# define __BEGIN_DECLS extern "C" {
# define __END_DECLS }
#else
# define __BEGIN_DECLS /* empty */
# define __END_DECLS /* empty */
#endif

#ifndef VOID
# if defined (__GNUC__) || __STDC__
#  define VOID void
# else
#  define VOID char
# endif
#endif

#ifndef PARAMS
#  if defined (__STDC__) || defined (_AIX) \
      || (defined (__mips) && defined (_SYSTYPE_SVR4)) \
      || defined(WIN32) || defined(__cplusplus)
#    define PARAMS(protos) protos
#  else
#    define PARAMS(protos) ()
#  endif
#endif

__BEGIN_DECLS

/*
 * A structure which records any global information liba2ps needs
 */
struct a2ps_job;

/* File liba2ps.h.extract */
/* From faces.h */
/* fonts used in language modes */
typedef enum face_t { 

/* From faces.h */
  Plain = 0, 
  Symbol = 1, 
  Keyword = 2, Keyword_strong = 3,
  Comment = 4, Comment_strong = 5,
  String = 6,
  Label = 7, Label_strong = 8,
  Error = 9

/* From faces.h */
} face_t;

/* From gen.h */
/* Print a single char C in FACE */
void a2ps_print_char PARAMS ((struct a2ps_job * job, 
			    int c, 
			    face_t face));
/* Print a C string (nul terminated) in FACE */
void a2ps_print_string PARAMS ((struct a2ps_job * job, 
			      const unsigned char * string, 
			      face_t face)); 
/* Print the N chars contained in BUFFER, in FACE */
void a2ps_print_buffer PARAMS ((struct a2ps_job * job, 
			      const unsigned char * buffer, 
			      size_t start, size_t end,
			      face_t face));
void a2ps_open_output_session PARAMS ((struct a2ps_job * job));
void a2ps_close_input_session PARAMS ((struct a2ps_job * job));
void a2ps_close_output_session PARAMS ((struct a2ps_job * job));


/* From jobs.h */
/* Return a newly allocated output session storage */
struct a2ps_job * a2ps_job_new PARAMS ((void));

/* Finalize it */
void a2ps_job_finalize PARAMS ((struct a2ps_job * job));

/* In the output session JOB, create a new input session NAME */
void a2ps_open_input_session PARAMS ((struct a2ps_job * job, unsigned char * name));

/* Free the memory used by JOB */
void a2ps_job_free PARAMS ((struct a2ps_job * job));

/* From confg.h */
/*
 * Read the configuration file
 */
int a2_read_config PARAMS ((struct a2ps_job * job,
			 const char *path, const char *file));

/*
 * Read the system's configuration file
 * (i.e., a2_read_config  (job, etc, a2ps.cfg))
 */
void a2_read_sys_config PARAMS ((struct a2ps_job * job));


__END_DECLS

#endif /* !defined(_LIBA2PS_H) */
